"""LangInsight LangChain integration.

TypeScript @langinsight/langchain と同じ仕様で、LLM の input/output トレースを
LangInsight に送信し、score() でフィードバックを送れます。
"""

from langinsight_langchain.callback_handler import CallbackHandler

__version__ = "0.0.1"

__all__ = ["CallbackHandler"]
